Name:           ugrep
Version:        6.3.0
Release:        %mkrel 1
Summary:        A more powerful, ultra fast, user-friendly, compatible grep
Group:          Text tools
License:        BSD-3-Clause
URL:            https://github.com/Genivia/ugrep
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(bzip3)
BuildRequires:  pkgconfig(libbrotlidec)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(zlib)

# Upstream does not allow building RE-flex as a shared library for ugrep to
# dynamically link against.
#
# https://github.com/Genivia/ugrep/issues/215
#
# To determine the bundled version, review the recent changes to the
# include/reflex directory.  Try to find each change in the separate RE-flex
# source.  Once you find a change that is in both, that will indicate which
# version of RE-flex is bundled.  This isn't an exact science, because changes
# happen in the bundled library first before being added to the RE-flex source.
#
# https://github.com/Genivia/ugrep/commits/master/include/reflex
# https://github.com/Genivia/RE-flex/tree/master/include/reflex
#
Provides:       bundled(libreflex) = 4.4.0


%description
Ugrep is an ultra fast, user-friendly, compatible grep.  Ugrep combines the
best features of other grep, adds new features, and searches fast.  Includes a
TUI and adds Google-like search, fuzzy search, hexdumps, searches nested
archives (zip, 7z, tar, pax, cpio), compressed files (gz, Z, bz2, lzma, xz,
lz4, zstd, brotli), pdfs, docs, and more.


%prep
%autosetup

%build
# https://github.com/Genivia/ugrep/issues/128
%configure \
        %ifarch %{arm}
        --disable-neon \
        %endif
        %ifarch %{ix86}
        --disable-sse2 \
        %endif
        --with-bzip3

%make_build

%install
%make_install

%check
%__make test

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/ug
%{_bindir}/ug+
%{_bindir}/ugrep
%{_bindir}/ugrep+
%{_bindir}/ugrep-indexer
%{_datadir}/ugrep/
%{_mandir}/man1/ug.1*
%{_mandir}/man1/ugrep.1*
%{_mandir}/man1/ugrep-indexer.1*

%{_datadir}/bash-completion/completions/*
%{_datadir}/fish/vendor_completions.d/*.fish
%{_datadir}/zsh/site-functions/*


%changelog
* Thu Aug 01 2024 daviddavid <daviddavid> 6.3.0-1.mga10
+ Revision: 2083289
- new version: 6.3.0

* Thu Jul 11 2024 daviddavid <daviddavid> 6.2.0-1.mga10
+ Revision: 2080646
- new version: 6.2.0

* Wed Jun 05 2024 daviddavid <daviddavid> 6.1.0-1.mga10
+ Revision: 2070116
- new version: 6.1.0

* Thu May 23 2024 daviddavid <daviddavid> 6.0.0-1.mga10
+ Revision: 2066269
- new version: 6.0.0

* Sun Apr 21 2024 daviddavid <daviddavid> 5.1.4-1.mga10
+ Revision: 2060215
- new version: 5.1.4

* Tue Mar 12 2024 daviddavid <daviddavid> 5.1.1-1.mga10
+ Revision: 2049542
- new version: 5.1.1

* Tue Mar 12 2024 daviddavid <daviddavid> 5.1.0-1.mga10
+ Revision: 2049251
- new version: 5.1.0

* Sun Feb 18 2024 daviddavid <daviddavid> 5.0.0-1.mga10
+ Revision: 2042314
- initial package ugrep

